pocketpose.datasets.skeletons - PocketPose 0.0.1 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Edit this page
Toggle table of contents sidebar

# `pocketpose.datasets.skeletons`

## Module Contents

### Classes

`Skeleton` | Base class for skeleton used by different datasets.
`COCOSkeleton` | Base class for skeleton used by different datasets.
`MPIISkeleton` | Base class for skeleton used by different datasets.
`BlazePoseSkeleton` | Base class for skeleton used by different datasets.
`H36MSkeleton` | Base class for skeleton used by different datasets.

class pocketpose.datasets.skeletons.Skeleton(name, nodes, edges)

  Bases: `abc.ABC`

  Base class for skeleton used by different datasets.

  Each skeleton is defined as a graph with nodes and edges, and a unique name to identify it.

  __str__() → str

    Return str(self).

class pocketpose.datasets.skeletons.COCOSkeleton

  Bases: `Skeleton`

  Base class for skeleton used by different datasets.

  Each skeleton is defined as a graph with nodes and edges, and a unique name to identify it.

class pocketpose.datasets.skeletons.MPIISkeleton

  Bases: `Skeleton`

  Base class for skeleton used by different datasets.

  Each skeleton is defined as a graph with nodes and edges, and a unique name to identify it.

class pocketpose.datasets.skeletons.BlazePoseSkeleton

  Bases: `Skeleton`

  Base class for skeleton used by different datasets.

  Each skeleton is defined as a graph with nodes and edges, and a unique name to identify it.

  get_coco_subset(skeleton)

class pocketpose.datasets.skeletons.H36MSkeleton

  Bases: `Skeleton`

  Base class for skeleton used by different datasets.

  Each skeleton is defined as a graph with nodes and edges, and a unique name to identify it.